import {
  __commonJS,
  __toESM
} from "./chunk-BXO7ZPPU.mjs";

// src/globals.ts
var require_globals = __commonJS({
  "src/globals.ts"() {
    "use strict";
    globalThis.process ||= { env: Netlify.env.toObject() };
  }
});

// src/index.ts
var import_globals = __toESM(require_globals());

// src/server.ts
import { createRequestHandler as createRemixRequestHandler } from "@netlify/remix-runtime";
function createRequestHandler({
  build,
  mode,
  getLoadContext
}) {
  const remixHandler = createRemixRequestHandler(build, mode);
  const assetPath = build.assets.url.split("/").slice(0, -1).join("/");
  return async (request, context) => {
    const { pathname } = new URL(request.url);
    if (pathname.startsWith(`${assetPath}/`)) {
      return;
    }
    try {
      const loadContext = await (getLoadContext == null ? void 0 : getLoadContext(request, context)) || context;
      const response = await remixHandler(request, loadContext);
      response.headers.set("x-nf-runtime", "Edge");
      if (response.status === 404) {
        const originResponse = await context.next({
          sendConditionalRequest: true
        });
        if (originResponse.status !== 404) {
          return originResponse;
        }
      }
      return response;
    } catch (error) {
      console.error(error);
      return new Response("Internal Error", { status: 500 });
    }
  };
}

// src/defaultRemixConfig.ts
var config = {
  server: "./server.ts",
  ignoredRouteFiles: ["**/.*"],
  serverBuildPath: ".netlify/edge-functions/server.js",
  serverConditions: ["deno", "worker"],
  serverDependenciesToBundle: "all",
  serverMainFields: ["module", "main"],
  serverModuleFormat: "esm",
  serverPlatform: "neutral"
};

// src/entry.server.tsx
import { RemixServer } from "@remix-run/react";
import { isbot } from "isbot";
import * as ReactDOMServer from "react-dom/server";
import { jsx } from "react/jsx-runtime";
async function handleRequest(request, responseStatusCode, responseHeaders, remixContext, loadContext) {
  const body = await ReactDOMServer.renderToReadableStream(/* @__PURE__ */ jsx(RemixServer, { context: remixContext, url: request.url }), {
    signal: request.signal,
    onError(error) {
      console.error(error);
      responseStatusCode = 500;
    }
  });
  if (isbot(request.headers.get("user-agent") || "")) {
    await body.allReady;
  }
  responseHeaders.set("Content-Type", "text/html");
  return new Response(body, {
    headers: responseHeaders,
    status: responseStatusCode
  });
}
export {
  config,
  createRequestHandler,
  handleRequest
};
