import "./chunk-BXO7ZPPU.mjs";

// src/plugin.ts
import { writeFile, mkdir, readdir } from "node:fs/promises";
import { join, relative, sep } from "node:path";
import { sep as posixSep } from "node:path/posix";

// package.json
var name = "@netlify/remix-edge-adapter";
var version = "3.3.0";

// src/plugin.ts
import { isBuiltin } from "node:module";
var SERVER_ID = "virtual:netlify-server";
var RESOLVED_SERVER_ID = `\0${SERVER_ID}`;
var toPosixPath = (path) => path.split(sep).join(posixSep);
var serverCode = (
  /* js */
  `
import { createRequestHandler } from "@netlify/remix-edge-adapter";
import * as build from "virtual:remix/server-build";
export default createRequestHandler({ build });
`
);
function generateEntrypoint(server, exclude = []) {
  return (
    /* js */
    `
    export { default } from "${server}";
    export const config = {
      name: "Remix server handler",
      generator: "${name}@${version}",
      cache: "manual",
      path: "/*",
      excludedPath: ${JSON.stringify(exclude)},
    };`
  );
}
function netlifyPlugin() {
  let resolvedConfig;
  let currentCommand;
  let isSsr;
  return {
    name: "vite-plugin-remix-netlify-edge",
    config(config, { command, isSsrBuild }) {
      var _a, _b;
      currentCommand = command;
      isSsr = isSsrBuild;
      if (command === "build") {
        if (isSsrBuild) {
          config.ssr = {
            ...config.ssr,
            target: "webworker",
            // Only externalize Node builtins
            noExternal: /^(?!node:).*$/
          };
          if (typeof ((_b = (_a = config.build) == null ? void 0 : _a.rollupOptions) == null ? void 0 : _b.input) === "string") {
            config.build.rollupOptions.input = {
              server: SERVER_ID,
              index: config.build.rollupOptions.input
            };
            if (config.build.rollupOptions.output && !Array.isArray(config.build.rollupOptions.output)) {
              config.build.rollupOptions.output.entryFileNames = "[name].js";
            }
          }
        }
      }
    },
    async configResolved(config) {
      resolvedConfig = config;
    },
    resolveId: {
      order: "pre",
      async handler(source, importer, options) {
        if (source === "virtual:netlify-server-entry") {
          if (currentCommand === "build" && options.ssr) {
            return this.resolve("@netlify/remix-edge-adapter/entry.server", importer, {
              ...options,
              skipSelf: true
            });
          } else {
            return this.resolve("@remix-run/dev/dist/config/defaults/entry.server.node", importer, {
              ...options,
              skipSelf: true
            });
          }
        }
        if (source === SERVER_ID) {
          return RESOLVED_SERVER_ID;
        }
        if (isSsr && isBuiltin(source)) {
          return {
            // Deno needs Node builtins to be prefixed
            id: source.startsWith("node:") ? source : `node:${source}`,
            external: true,
            moduleSideEffects: false
          };
        }
        return null;
      }
    },
    load(id) {
      if (id === RESOLVED_SERVER_ID) {
        return serverCode;
      }
    },
    async writeBundle() {
      if (currentCommand === "build" && isSsr) {
        const exclude = ["/.netlify/*"];
        try {
          const clientDirectory = join(resolvedConfig.build.outDir, "..", "client");
          const entries = await readdir(clientDirectory, { withFileTypes: true });
          for (const entry of entries) {
            if (entry.isDirectory()) {
              exclude.push(`/${entry.name}/*`);
            } else if (entry.isFile()) {
              exclude.push(`/${entry.name}`);
            }
          }
        } catch {
        }
        const edgeFunctionsDirectory = join(resolvedConfig.root, ".netlify/edge-functions");
        await mkdir(edgeFunctionsDirectory, { recursive: true });
        const serverPath = join(resolvedConfig.build.outDir, "server.js");
        const relativeServerPath = toPosixPath(relative(edgeFunctionsDirectory, serverPath));
        await writeFile(
          join(edgeFunctionsDirectory, "remix-server.mjs"),
          generateEntrypoint(relativeServerPath, exclude)
        );
      }
    }
  };
}
export {
  netlifyPlugin
};
